CPNest
======

Parallel nested sampling in python

----

© 2015-2019 Walter Del Pozzo, John Veitch

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
   :alt: MIT license
   :target: https://github.com/johnveitch/cpnest/blob/master/LICENSE

walter.delpozzo@ligo.org,
john.veitch@ligo.org

CPNest is a python module for performing Bayesian Inference.
Documentation at `GitHub Pages <https://johnveitch.github.io/cpnest/>`_.


If you use this software, please cite our DOI:

.. image:: https://zenodo.org/badge/74378989.svg
   :alt: 10.5281/zenodo.835874
   :target: https://zenodo.org/badge/latestdoi/74378989

